<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <location filename="src/AboutView.cpp" line="21"/>
        <source>There&apos;s life outside the browser!</source>
        <translation>Istnieje życie poza przeglądarką!</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="22"/>
        <source>Version %1</source>
        <translation>Wersja %1</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="26"/>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 jest wolnym oprogramowaniem, ale jego rozwój pochłania cenney czas.</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="27"/>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Proszę &lt;a href=&apos;%1&apos;&gt;wesprzyj nas darowizną&lt;/a&gt; żybyśmy mogli ciągle rozwijać %2.</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="31"/>
        <source>You may want to try my other apps as well:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="34"/>
        <source>%1, a YouTube music player</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="38"/>
        <source>%1, a music player</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="44"/>
        <source>Translate %1 to your native language using %2</source>
        <translation>Przetłumacz %1 na swój język używając %2</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="49"/>
        <source>Icon designed by %1.</source>
        <translation>Ikony zaprojektowane przez %1.</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="53"/>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Wydane na licencji&lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="65"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="src/AboutView.h" line="25"/>
        <source>About</source>
        <translation>O programie Minitube</translation>
    </message>
    <message>
        <location filename="src/AboutView.h" line="27"/>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>To co zawsze chcieliście wiedzieć o %1 ale nigdy się nie odważyliście zapytać</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <location filename="src/searchlineedit.cpp" line="56"/>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
</context>
<context>
    <name>DemoStartupView</name>
    <message>
        <location filename="local/src/demostartupview.cpp" line="35"/>
        <source>Please license %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="39"/>
        <source>This demo has expired.</source>
        <translation>Te demo wygasło.</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="41"/>
        <source>The full version allows you to download videos longer than %1 minutes and to watch videos without interruptions.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="43"/>
        <source>This demo will expire in %1 days.</source>
        <translation>Te demo wygasa za %1 dni.</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="45"/>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="57"/>
        <source>Use Demo</source>
        <translation>Użyj Dema</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="65"/>
        <source>Get the full version</source>
        <translation>Pobierz pełną wersję</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <location filename="src/downloaditem.cpp" line="308"/>
        <source>bytes</source>
        <translation>bajty</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="311"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="314"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="330"/>
        <source>bytes/sec</source>
        <translation>bajtów/sekundę</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="333"/>
        <source>KB/sec</source>
        <translation>KB/sek</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="336"/>
        <source>MB/sec</source>
        <translation>MB/sek</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="342"/>
        <source>seconds</source>
        <translation>sekund</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="345"/>
        <source>minutes</source>
        <translation>minut</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="348"/>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 pozostało do końca</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <location filename="src/downloadmanager.cpp" line="47"/>
        <source>This is just the demo version of %1.</source>
        <translation>To jest tylko wersja demo%1.</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="49"/>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation>Może jedynie pobierać filmy krótsze niż%1 minut, więc można przetestować funkcje pobierania.</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="55"/>
        <source>Continue</source>
        <translation>Kontynuuj</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="56"/>
        <source>Get the full version</source>
        <translation>Pobierz pełną wersję</translation>
    </message>
    <message numerus="yes">
        <location filename="src/downloadmanager.cpp" line="137"/>
        <source>%n Download(s)</source>
        <translation><numerusform>%n Pobieranie</numerusform><numerusform>%n Pobieranie</numerusform><numerusform>%n Pobieranie</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <location filename="src/downloadsettings.cpp" line="14"/>
        <source>Change location...</source>
        <translation>Zmień katalog pobierania...</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="38"/>
        <source>Choose the download location</source>
        <translation>Wybierz katalog pobierania</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="49"/>
        <source>Download location changed.</source>
        <translation>Katalog pobierania został zmieniony.</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="51"/>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Aktualnie pobierane pliki zostaną we wcześniejszym katalogu pobierania.</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="63"/>
        <source>Downloading to: %1</source>
        <translation>Pobierane do: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <location filename="src/downloadview.cpp" line="18"/>
        <location filename="src/downloadview.h" line="22"/>
        <source>Downloads</source>
        <translation>Pobrane pliki</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <location filename="src/globalshortcuts.cpp" line="16"/>
        <source>Play</source>
        <translation>Odtwarzaj</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="17"/>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="18"/>
        <source>Play/Pause</source>
        <translation>Odtwarzaj/Wstrzymaj</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="19"/>
        <source>Stop</source>
        <translation>Zatrzymaj</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="20"/>
        <source>Stop playing after current track</source>
        <translation>Zatrzymaj odtwarzanie po tej ścieżce</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="21"/>
        <source>Next track</source>
        <translation>Następny</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="22"/>
        <source>Previous track</source>
        <translation>Poprzedni</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="23"/>
        <source>Increase volume</source>
        <translation>Głośniej</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="24"/>
        <source>Decrease volume</source>
        <translation>Ciszej</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="25"/>
        <source>Mute</source>
        <translation>Wycisz</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="26"/>
        <source>Seek forward</source>
        <translation>Przewiń w przód</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="27"/>
        <source>Seek backward</source>
        <translation>Przewiń w tył</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <location filename="src/ListModel.cpp" line="51"/>
        <source>Searching...</source>
        <translation>Szukam...</translation>
    </message>
    <message>
        <location filename="src/ListModel.cpp" line="52"/>
        <source>Show %1 More</source>
        <translation>Pokaż kolejne %1</translation>
    </message>
    <message>
        <location filename="src/ListModel.cpp" line="53"/>
        <source>No videos</source>
        <translation>Brak plików</translation>
    </message>
    <message>
        <location filename="src/ListModel.cpp" line="54"/>
        <source>No more videos</source>
        <translation>Nie ma więcej plików</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <location filename="src/loadingwidget.cpp" line="71"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="src/MainWindow.cpp" line="160"/>
        <source>&amp;Stop</source>
        <translation>&amp;Zatrzymaj</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="161"/>
        <source>Stop playback and go back to the search view</source>
        <translation>Zatrzymaj odtwarzanie i wróć do wyszukiwania</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="179"/>
        <source>S&amp;kip</source>
        <translation>Prze&amp;skocz dalej</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="180"/>
        <source>Skip to the next video</source>
        <translation>Skocz do następnego pliku wideo</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="186"/>
        <location filename="src/MainWindow.cpp" line="835"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pauza</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="187"/>
        <location filename="src/MainWindow.cpp" line="836"/>
        <source>Pause playback</source>
        <translation>Wstrzymaj odtwarzanie</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="193"/>
        <source>&amp;Full Screen</source>
        <translation>Pełny ekran (&amp;F)</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="194"/>
        <source>Go full screen</source>
        <translation>Przełącz na pełny ekran</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="210"/>
        <source>Hide the playlist and the toolbar</source>
        <translation>Ukryj listę odtwarzania i pasek narzędzi</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="223"/>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Otwórz na stronie Youtube i wstrzymaj odtwarzanie</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="230"/>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Kopiuj link aktualnie odtwarzanego video do schowka</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="237"/>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopiuj adres URL odtwarzanego wideo do schowka</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="244"/>
        <source>Find other video parts hopefully in the right order</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="250"/>
        <source>&amp;Remove</source>
        <translation>Usuń (&amp;D)</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="251"/>
        <source>Remove the selected videos from the playlist</source>
        <translation>Usuń wybrane pliki z listy odtwarzania</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="257"/>
        <source>Move &amp;Up</source>
        <translation>Przenieś &amp;Wyżej</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="258"/>
        <source>Move up the selected videos in the playlist</source>
        <translation>Przenieś wyżej zaznaczony plik w liście odtwarzania</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="264"/>
        <source>Move &amp;Down</source>
        <translation>Przenieś &amp;Niżej</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="265"/>
        <source>Move down the selected videos in the playlist</source>
        <translation>Przenieś niżej zaznaczony plik w liście odtwarzania</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="276"/>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Wyczyść historię wyszukiwania. NIEODWRACALNIE.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="281"/>
        <source>&amp;Quit</source>
        <translation>Wyjdź (&amp;Q)</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="284"/>
        <source>Bye</source>
        <translation>Żegnaj</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="288"/>
        <source>&amp;Website</source>
        <translation>Strona domowa projektu (&amp;W)</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="290"/>
        <source>%1 on the Web</source>
        <translation>%1 w sieci</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="296"/>
        <source>Please support the continued development of %1</source>
        <translation>Prosimy o wsparcie dla dalszego rozwoju %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="301"/>
        <source>&amp;About</source>
        <translation>O programie (&amp;A)</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="303"/>
        <source>Info about %1</source>
        <translation>Informacje o %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="311"/>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="330"/>
        <source>Mute volume</source>
        <translation>Wycisz</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="359"/>
        <location filename="src/MainWindow.cpp" line="1179"/>
        <source>&amp;Downloads</source>
        <translation>&amp;Pobrane</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="360"/>
        <source>Show details about video downloads</source>
        <translation>Pokaż szczegóły o pobranych plikach</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="368"/>
        <source>&amp;Download</source>
        <translation>&amp;Pobierz</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="369"/>
        <source>Download the current video</source>
        <translation>Pobierz aktualny plik</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="381"/>
        <source>Share the current video using %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="393"/>
        <source>&amp;Email</source>
        <translation>&amp;E-mail</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="394"/>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="398"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="403"/>
        <source>&amp;Float on Top</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="408"/>
        <source>&amp;Stop After This Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="445"/>
        <source>&amp;Application</source>
        <translation>&amp;Aplikacje</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="447"/>
        <source>Buy %1...</source>
        <translation>Kup %1...</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="458"/>
        <source>&amp;Playback</source>
        <translation>&amp;Odtwarzanie</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="472"/>
        <source>&amp;Playlist</source>
        <translation>&amp;Lista odtwarzania</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="479"/>
        <source>&amp;Video</source>
        <translation>&amp;Wideo</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="490"/>
        <source>&amp;View</source>
        <translation>&amp;Widok</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="497"/>
        <source>&amp;Share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="509"/>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="586"/>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Wciścnij %1 żeby zwiększyć głośność, %2 żeby zmiejszyć głośność</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="748"/>
        <location filename="src/MainWindow.cpp" line="754"/>
        <source>Opening %1</source>
        <translation>Otwieranie %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="787"/>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Czy na pewno chcesz zamknąć %1 w trakcie pobierania???</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="788"/>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Jeśli zamkniesz %1 teraz, To pobieranie będzie anulowane.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="793"/>
        <source>Close and cancel download</source>
        <translation>Zamnij i anuluj pobieranie</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="794"/>
        <source>Wait for download to finish</source>
        <translation>Poczekaj na zakończenie pobierania</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="940"/>
        <source>Leave &amp;Full Screen</source>
        <translation>Opuść &amp;tryb pełnoekranowy</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1283"/>
        <source>%1 version %2 is now available.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1297"/>
        <source>Remind me later</source>
        <translation>Przypomnij mi później</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1294"/>
        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1301"/>
        <source>Update</source>
        <translation>Aktualizuj</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="828"/>
        <source>Error: %1</source>
        <translation>Błąd %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="169"/>
        <source>P&amp;revious</source>
        <translation>Pop&amp;rzedni</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="170"/>
        <source>Go back to the previous track</source>
        <translation>Powrót do poprzedniego utworu</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="209"/>
        <source>&amp;Compact Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="222"/>
        <source>Open the &amp;YouTube Page</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="229"/>
        <source>Copy the YouTube &amp;Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="236"/>
        <source>Copy the Video Stream &amp;URL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="243"/>
        <source>Find Video &amp;Parts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="271"/>
        <source>&amp;Clear Recent Searches</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="295"/>
        <source>Make a &amp;Donation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="352"/>
        <source>&amp;Manually Start Playing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="353"/>
        <source>Manually start playing videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="848"/>
        <source>&amp;Play</source>
        <translation>&amp;Odtwarzaj</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="849"/>
        <source>Resume playback</source>
        <translation>Kontynuuj odtwarzanie</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1055"/>
        <source>Remaining time: %1</source>
        <translation>Pozostały czas %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1113"/>
        <source>Volume at %1%</source>
        <translation>Głośność na %1%</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1119"/>
        <source>Volume is muted</source>
        <translation>Dźwięk jest wyciszony</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1122"/>
        <source>Volume is unmuted</source>
        <translation>Przywrócono dźwięk</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1129"/>
        <source>Maximum video definition set to %1</source>
        <translation>Maksymalna rozdzielczość wideo ustawiona na %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1165"/>
        <source>Your privacy is now safe</source>
        <translation>Twoja prywatność jest teraz bezpieczna</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1180"/>
        <source>Downloads complete</source>
        <translation>Pobieranie ukończone</translation>
    </message>
    <message>
        <location filename="local/mac/macsupport.cpp" line="58"/>
        <source>&amp;Window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="local/mac/macsupport.cpp" line="61"/>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimalizuj</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <location filename="src/MediaView.cpp" line="35"/>
        <source>Most relevant</source>
        <translation>Najlepiej pasujące</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="42"/>
        <source>Most recent</source>
        <translation>Ostatnie</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="49"/>
        <source>Most viewed</source>
        <translation>Najczęściej odtwarzane</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="521"/>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Teraz możesz wkleić link Youtube do innej aplikacji</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="529"/>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Teraz możesz wkleić URL do innej aplikacji</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="530"/>
        <source>The link will be valid only for a limited time.</source>
        <translation>Link będzie ważny tylko przez ograniczony czas.</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="629"/>
        <source>This is just the demo version of %1.</source>
        <translation>To jest tylko wersja demo %1.</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="630"/>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation>Pozwala Ci to na testowanie i sprawdzenie działania aplikacji.</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="660"/>
        <source>Continue</source>
        <translation>Kontynuuj</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="749"/>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>z</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="761"/>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>część</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="763"/>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>odcinek</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="821"/>
        <source>Sent from %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="637"/>
        <source>Get the full version</source>
        <translation>Pobierz pełną wersję</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="682"/>
        <source>Downloading %1</source>
        <translation>Pobieranie %1</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <location filename="src/networkaccess.cpp" line="214"/>
        <source>Network error: %1</source>
        <translation>Błąd sieci %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="170"/>
        <source>%1 views</source>
        <translation>%1 widziane</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="286"/>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 of %2 (%3) — %4</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="293"/>
        <source>Preparing</source>
        <translation>Przegotowuję</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="295"/>
        <source>Failed</source>
        <translation>Nieudane</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="297"/>
        <source>Completed</source>
        <translation>Zakończone</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="299"/>
        <source>Stopped</source>
        <translation>Zatrzymane</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="335"/>
        <source>Stop downloading</source>
        <translation>Zatrzymaj pobieranie</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="345"/>
        <source>Show in %1</source>
        <translation>Pokaż w %1</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="347"/>
        <source>Open parent folder</source>
        <translation>Otwórz katalog macierzysty</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="356"/>
        <source>Restart downloading</source>
        <translation>Pobierz od nowa</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <location filename="src/searchlineedit.cpp" line="177"/>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <location filename="src/SearchView.cpp" line="79"/>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Witaj w &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="46"/>
        <source>Get the full version</source>
        <translation>Pobierz pełną wersję</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="93"/>
        <source>Enter</source>
        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
        <translation>Zatwierdź</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="98"/>
        <source>a keyword</source>
        <translation>słowo kluczowe</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="99"/>
        <source>a channel</source>
        <translation>kanał</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="104"/>
        <source>to start watching videos.</source>
        <translation>aby rozpocząć oglądanie</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="128"/>
        <source>Watch</source>
        <translation>Oglądaj</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="146"/>
        <source>Recent keywords</source>
        <translation>Ostatnio szukane</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="159"/>
        <source>Recent channels</source>
        <translation>Odwiedzone kanały</translation>
    </message>
    <message>
        <location filename="src/SearchView.h" line="26"/>
        <source>Make yourself comfortable</source>
        <translation>Czuj sie komfortowo</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <location filename="src/video.cpp" line="200"/>
        <source>Cannot get video stream for %1</source>
        <translation>Nie można uzyskać dostępu do %1</translation>
    </message>
    <message>
        <location filename="src/video.cpp" line="218"/>
        <source>Network error: %1 for %2</source>
        <translation>Błąd sieci: %1 for %2</translation>
    </message>
</context>
</TS>